@@ -19,10 +19,17 @@ class WowMySQLClient:
     """
     WowMySQL client for interacting with your database via REST API.
     
+    This client is used for DATABASE OPERATIONS (CRUD on tables).
+    Use Service Role Key or Anonymous Key for authentication.
+    
+    Key Types:
+        - Service Role Key: Full access to all database operations (recommended for server-side)
+        - Anonymous Key: Public access with limited permissions (for client-side/public access)
+    
     Example:
         >>> client = WowMySQLClient(
         ...     project_url="myproject",
-        ...     api_key="your_api_key"
+        ...     api_key="wowbase_service_..."  # Service Role Key or Anonymous Key
         ... )
         >>> users = client.table("users").get()
     """
@@ -37,19 +44,25 @@ class WowMySQLClient:
         verify_ssl: bool = True
     ):
         """
-        Initialize WowMySQL client.
+        Initialize WowMySQL client for DATABASE OPERATIONS.
         
         Args:
             project_url: Project subdomain or full URL
                 Examples:
                 - Just slug: "myproject" (will construct URL automatically)
                 - Full URL: "https://myproject.wowmysql.com/api"
-            api_key: API key for authentication
+            api_key: API key for database operations authentication.
+                Use Service Role Key (wowbase_service_...) or Anonymous Key (wowbase_anon_...).
+                This key is used for DATABASE OPERATIONS only, not for authentication services.
             base_domain: Base domain (default: wowmysql.com)
             secure: Use HTTPS (default: True)
             timeout: Request timeout in seconds (default: 30)
             verify_ssl: Verify SSL certificates (default: True).
                 Set to False for development/self-signed certs
+        
+        Note:
+            For AUTHENTICATION OPERATIONS (OAuth, sign-in, sign-up), use ProjectAuthClient instead.
+            ProjectAuthClient uses Public API Key (wowbase_auth_...) or Service Role Key.
         """
         # Build base URL
         if project_url.startswith("http://") or project_url.startswith("https://"):
